﻿Imports Wiker.WIDatabase
Imports System.Text
Module Module1

    Sub Main()
    Dim WIDB As WIDatabase
        Dim DBInfo As CDatabaseInfo
        Dim Str As String, ColumnDataStr As String
        Dim ColumnDataInt As Integer
        Dim StrB As StringBuilder

        ColumnDataStr = ""
        ColumnDataInt = 0

        ' Create DatabaseInfo object with login info  

        DBInfo = New CDatabaseInfo()
        DBInfo.DatabaseType = eDatabaseType.SQLite
        DBInfo.Location = "\WIDatabase\Samples"
        DBInfo.DBName = "SQLite.db3"
        DBInfo.Password = ""
        DBInfo.Port = 0
        DBInfo.Username = ""

        ' Create the object 

        WIDB = New WIDatabase(DBInfo)

        ' Change to wait only 30 seconds for connection time out */
        SETTINGS.ConnectionTimeOut = 30

        ' Wait 30 seconds for Query to time out */
        SETTINGS.QueryTimeOut = 30

        ' Only Trim beginning of data */
        SETTINGS.Trimming = eTrim.Start

        ' Do not make any changes to SQL Variable */
        SETTINGS.PrepareSQLVariable = False

        ' Call function DatabaseFailureCallBack() upon Database failure */
        SETTINGS.DatabaseFailureCallBack = AddressOf DatabaseFailureCallBack

        ' Call function DebugLogCallBack() to Log debug messages */
        SETTINGS.DebugLogCallBack = AddressOf DebugLogCallBack


        ' Check the last error 

        If WIDB.LastError <> eDBErrorCodes.None Then
            Str = String.Format("Error occured while executing the select:" & vbLf & "{0}" & vbLf & "{1}", WIDB.LastError, WIDB.LastErrorMessage)
            Console.WriteLine(Str)
            Return
        End If

        ' Check to see if DB exists 

        If Not WIDB.Database.Exists() Then
            Str = String.Format("Database '{0}' does not exist. Please create it.", DBInfo.DBName)
            Console.WriteLine(Str)
            Return
        End If

        ' Check the last error  

        If WIDB.LastError <> eDBErrorCodes.None Then
            Str = String.Format("Error occured while executing the select:" & vbLf & "{0}" & vbLf & "{1}", WIDB.LastError, WIDB.LastErrorMessage)
            Console.WriteLine(Str)
            Return
        End If

        ' Make Sure the table exists before selecting 

        If Not WIDB.Table.Exists("tblAddress") Then
            Str = String.Format("The table 'tblAddress' in database '{0}' does not exist.", DBInfo.DBName)
            Console.WriteLine(Str)
            Return
        End If

        ' Check the last error  

        If WIDB.LastError <> eDBErrorCodes.None Then
            Str = String.Format("Error occured while executing the select:" & vbLf & "{0}" & vbLf & "{1}", WIDB.LastError, WIDB.LastErrorMessage)
            Console.WriteLine(Str)
            Return
        End If

        '
        '            See the Select example for more information
        '         


        WIDB.[Search].Clear()
        WIDB.[Search].Column("AddressID")
        WIDB.[Search].Column("Address1")
        WIDB.[Search].Column("Address2")
        WIDB.[Search].Column("City")
        WIDB.[Search].Column("State")
        WIDB.[Search].Column("ZipCode")
        WIDB.[Search].Table("tblAddress")

        ' check if execution succeeded 

        If Not WIDB.[Search].Execute() Then
            Str = String.Format("Error occured while executing the select:" & vbLf & "{0}" & vbLf & "{1}", WIDB.LastError, WIDB.LastErrorMessage)
            Console.WriteLine(Str)
            Return
        End If

        ' Check the last error  

        If WIDB.LastError <> eDBErrorCodes.None Then
            Str = String.Format("Error occured while executing the select:" & vbLf & "{0}" & vbLf & "{1}", WIDB.LastError, WIDB.LastErrorMessage)
            Console.WriteLine(Str)
            Return
        End If

        Console.WriteLine("| AddressID | Address1 | Address2 | City | State | Zip |")

        ' read the results of the query 

        While WIDB.[Search].Read()
            ' Check the last error  

            If WIDB.LastError <> eDBErrorCodes.None Then
                Str = String.Format("Error occured while executing the select:" & vbLf & "{0}" & vbLf & "{1}", WIDB.LastError, WIDB.LastErrorMessage)
                Console.WriteLine(Str)
                Return
            End If

            StrB = New StringBuilder()

            If Not WIDB.[Search].Get("AddressID", ColumnDataInt) Then
                ColumnDataInt = -1
            End If

            StrB.AppendFormat("| {0} ", ColumnDataInt)

            If Not WIDB.[Search].Get("Address1", ColumnDataStr) Then
                ColumnDataStr = "ERROR GETTING COLUMN"
            End If
            StrB.AppendFormat("| {0} ", ColumnDataStr)

            If Not WIDB.[Search].Get("Address2", ColumnDataStr) Then
                ColumnDataStr = "ERROR GETTING COLUMN"
            End If
            StrB.AppendFormat("| {0} ", ColumnDataStr)

            If Not WIDB.[Search].Get("City", ColumnDataStr) Then
                ColumnDataStr = "ERROR GETTING COLUMN"
            End If
            StrB.AppendFormat("| {0} ", ColumnDataStr)

            If Not WIDB.[Search].Get("State", ColumnDataStr) Then
                ColumnDataStr = "ERROR GETTING COLUMN"
            End If
            StrB.AppendFormat("| {0} ", ColumnDataStr)

            If Not WIDB.[Search].Get("ZipCode", ColumnDataStr) Then
                ColumnDataStr = "ERROR GETTING COLUMN"
            End If
            StrB.AppendFormat("| {0} ", ColumnDataStr)

            Console.WriteLine(StrB.ToString())
        End While

        Console.WriteLine()
        Console.WriteLine(String.Format("Statement sent to the Database:" & vbLf & "{0}", WIDB.SQLStatement))

        ' Good practice is to close the DB when finished 

        WIDB.Close()

    End Sub

    Private Function DatabaseFailureCallBack(ByVal errorCode As eDBErrorCodes) As Boolean
        Console.WriteLine(String.Format("DBFailureCallback {0}", errorCode.ToString()))
        Return (True)
    End Function

    Private Sub DebugLogCallBack(ByVal message As String, ByVal ex As Exception)
        Console.WriteLine(String.Format("{0}" & vbLf & "{1}", message, ex.Message))
    End Sub

End Module
