﻿/*******************************************************************************
File        : Create.cs
Description : 
--------------------------------------------------------------------------------
Functions:
--------------------------------------------------------------------------------
History:
2011/04/27 WLM Created
*******************************************************************************/
using System;
using System.Windows.Forms;
using System.Drawing;
using Wiker.WIDatabase;

namespace WIDatabaseSample
{
/*******************************************************************************
Class        : MainForm
Description  : 
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
public partial class MainForm
{
/*******************************************************************************
Function    : CreateTables()
Description : 
Parameters  : bool
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/27 WLM Created
*******************************************************************************/
public bool CreateTables()
{
string Str;
CDatabaseInfo DatabaseInfo;
bool Result;

DatabaseInfo = GetDBInfo();

if (UseSELECT)
   Str = string.Format("CREATE {0} Tables Using SELECT", DatabaseInfo.DatabaseType.ToString());

else
   Str = string.Format("CREATE {0} Tables Using WIDatabase", DatabaseInfo.DatabaseType.ToString());

if (MessageBox.Show(Str, "", MessageBoxButtons.YesNo) == DialogResult.No)
   return(false);

/*----------------------------------------------------------------------------*/

if (UseSELECT)
   {
   switch (DatabaseInfo.DatabaseType)
      {
      case eDatabaseType.SQL:
         Result = CreateSQLSELECT(DatabaseInfo);
      break;

      case eDatabaseType.SQLite:
         Result = CreateSQLiteSELECT(DatabaseInfo);
      break;

      case eDatabaseType.MySql:
         Result = CreateMySqlSELECT(DatabaseInfo);
      break;

      default:
         return(false);
      }
   }

else
   Result = CreateWI();

return(Result);
}
/*******************************************************************************
Function    : CreateWI()
Description : 
Parameters  : None
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/06 WLM Created
*******************************************************************************/
public bool CreateWI()
{
WIDatabase WIDB;
string Str;

/* Create Connection And Open Database */
WIDB = new WIDatabase(GetDBInfo());

/* Create tblAddress Table */
WIDB.Table.Clear();
WIDB.Table.Column("AddressID", eDataType.Int32);
WIDB.Table.Column("Address1", eDataType.VarChar, 255);
WIDB.Table.Column("Address2", eDataType.VarChar, 255);
WIDB.Table.Column("City", eDataType.VarChar, 255);
WIDB.Table.Column("State", eDataType.VarChar, 255);
WIDB.Table.Column("ZipCode", eDataType.VarChar, 12);

WIDB.Table.PrimaryColumn("AddressID");
WIDB.Table.AutoIncrementColumn("AddressID");

if (!WIDB.Table.Create("tblAddress"))
   {
   Str = string.Format("Failed to create table tblAddress\nLastError = {0}\n{1}",
      WIDB.LastError.ToString(), WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/
/* Create tblCompany Table */

WIDB.Table.Clear();
WIDB.Table.Column("CompanyID", eDataType.Int32);
WIDB.Table.Column("AddressID", eDataType.Int32);
WIDB.Table.Column("Name", eDataType.VarChar, 255);
WIDB.Table.Column("LogoID", eDataType.Int32);
WIDB.Table.Column("WebSite", eDataType.VarChar, 255);
WIDB.Table.Column("Active", eDataType.Bool);

/*----------------------------------------------------------------------------*/

WIDB.Table.PrimaryColumn("CompanyID");
WIDB.Table.AutoIncrementColumn("CompanyID");

if (!WIDB.Table.Create("tblCompany"))
   {
   Str = string.Format("Failed to create table tblCompany\nLastError = {0}\n{1}",
      WIDB.LastError.ToString(), WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/
/* Create tblImage Table */

WIDB.Table.Clear();
WIDB.Table.Column("ImageID", eDataType.Int32);
WIDB.Table.Column("ImageData", eDataType.Image);

WIDB.Table.PrimaryColumn("ImageID");
WIDB.Table.AutoIncrementColumn("ImageID");

if (!WIDB.Table.Create("tblImage"))
   {
   Str = string.Format("Failed to create table tblImage\nLastError = {0}\n{1}",
      WIDB.LastError.ToString(), WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/
/* Create tblPerson Table */

WIDB.Table.Clear();
WIDB.Table.Column("PersonID", eDataType.Int32);
WIDB.Table.Column("AddressID", eDataType.Int32);
WIDB.Table.Column("CompanyID", eDataType.Int32);
WIDB.Table.Column("Name", eDataType.VarChar, 255);
WIDB.Table.Column("PhotoID", eDataType.Int32);
WIDB.Table.Column("Active", eDataType.Bool);

WIDB.Table.PrimaryColumn("PersonID");
WIDB.Table.AutoIncrementColumn("PersonID");

if (!WIDB.Table.Create("tblPerson"))
   {
   Str = string.Format("Failed to create table tblPerson\nLastError = {0}\n{1}",
      WIDB.LastError.ToString(), WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/
/* Create tblPhone Table */

WIDB.Table.Clear();
WIDB.Table.Column("PhoneID", eDataType.Int32);
WIDB.Table.Column("CompanyID", eDataType.Int32);
WIDB.Table.Column("PersonID", eDataType.Int32);
WIDB.Table.Column("Type", eDataType.Int32);
WIDB.Table.Column("Number", eDataType.VarChar, 25);

WIDB.Table.PrimaryColumn("PhoneID");
WIDB.Table.AutoIncrementColumn("PhoneID");

if (!WIDB.Table.Create("tblPhone"))
   {
   Str = string.Format("Failed to create table tblPhone\nLastError = {0}\n{1}",
      WIDB.LastError.ToString(), WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

return(true);
}
} /* End Of Class MainForm */
} /* End Of NameSpace WIDatabaseSample */